.. image:: https://travis-ci.org/timcera/swmmtoolbox.svg?branch=master
    :target: https://travis-ci.org/timcera/swmmtoolbox
    :height: 20

.. image:: https://coveralls.io/repos/timcera/swmmtoolbox/badge.png?branch=master
    :target: https://coveralls.io/r/timcera/swmmtoolbox?branch=master
    :height: 20

.. image:: https://img.shields.io/pypi/v/swmmtoolbox.svg
    :alt: Latest release
    :target: https://pypi.python.org/pypi/swmmtoolbox

.. image:: http://img.shields.io/badge/license-BSD-lightgrey.svg
    :alt: swmmtoolbox license
    :target: https://pypi.python.org/pypi/swmmtoolbox/

SWMMToolbox - Overview
----------------------
The swmmtoolbox is a Python script to read the Storm Water Management Model
(SWMM) version 5 binary output files.

Requirements
============
Python - of course

The 'mando' library which should have been installed as a requirement.

The 'tstoolbox' library and command line tool which should have been installed
as a requirement.

The PANDAS library which normally comes installed as part of Python
distributions such as Anaconda, Enthought, or Pythonxy.

Installation
============
Should be easy as ``pip install swmmtoolbox`` OR ``easy_install swmmtoolbox``
depending on your choice of Python package managers.
